@@ -7,9 +7,8 @@
 #  Authors: Revva Konstantin <k.revva@abm-jsc.ru>
 
 
-from detector_connector import DetectorKafkaConnector
+from detector_connector import DetectorKafkaConnector, DetectorAnalyzeResult
 
-from .shift_analyze_result import ShiftAnalyzeResult
 
 
 class ShiftDetectorKafkaConnector(DetectorKafkaConnector):
@@ -17,4 +16,4 @@ class ShiftDetectorKafkaConnector(DetectorKafkaConnector):
     Config = DetectorKafkaConnector.Config
 
     def __init__(self, config: Config, context: Context):
-        super().__init__(config=config, context=context, detector_analyze_result_type=ShiftAnalyzeResult)
+        super().__init__(config=config, context=context, detector_analyze_result_type=DetectorAnalyzeResult)
